import React from 'react';
import ReactDOM from 'react-dom';
import {
  interpolateYlOrRed,
  scaleSequential,
  max,
} from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const selectedYear = '2017';

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();

  if (!worldAtlas || !data) {
    return <pre>Loading...</pre>;
  }

  const filteredData = data.filter(
    (d) => d.Year === selectedYear
  );

  const colorValue = (d) => d.aids;
  const colorScale = scaleSequential(
    interpolateYlOrRed
  ).domain([0, max(data, colorValue)]);

  const rowByCountry = new Map();
  filteredData.forEach((d) => {
    rowByCountry.set(d.Entity, d);
  });

  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByCountry={rowByCountry}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
